summaryrefslogtreecommitdiff
path: root/Magefile.go
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2026-05-04 23:28:48 +0300
committerPaul Buetow <paul@buetow.org>2026-05-04 23:28:48 +0300
commitd0a5493e9710f4b515ad5825aeee3c0102d03ee7 (patch)
tree8f8ddcbf96beb517252ce525060382f22b83fa6a /Magefile.go
parent2f09915d3da7a23574e1a90fa70eb1af1cdf830a (diff)
renamemain
Diffstat (limited to 'Magefile.go')
-rw-r--r--Magefile.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/Magefile.go b/Magefile.go
index 015f0f1..e344a3f 100644
--- a/Magefile.go
+++ b/Magefile.go
@@ -1,6 +1,6 @@
//go:build mage
// Package main provides build targets for anelephantinachinashop.
// Targets follow the same style as other projects: Default builds, Test runs tests,
// Bench runs benchmarks, Install copies binary to GOPATH/bin.
package main
@@ -14,7 +14,7 @@ import (
"github.com/magefile/mage/sh"
)
-const binaryName = "anelephantinachinashop"
+const binaryName = "rampage"
// Default builds the project.
func Default() {
@@ -23,7 +23,7 @@ func Default() {
// Build compiles the binary.
func Build() error {
- return sh.RunV("go", "build", "-o", binaryName, "./cmd/anelephantinachinashop")
+ return sh.RunV("go", "build", "-o", binaryName, "./cmd/rampage")
}
// Test runs all unit tests.
@@ -1,6 +1,6 @@
//go:build mage
-// Package main provides build targets for anelephantinachinashop.
+// Package main provides build targets for rampage.
// Targets follow the same style as other projects: Default builds, Test runs tests,
// Bench runs benchmarks, Install copies binary to GOPATH/bin.